==> ViennaRNA-2.4.2.tar.gz: ViennaRNA-2.4.2/doc/html/group__energy__parameters.js <==
var group__energy__parameters =
[
    [ "Reading/Writing Energy Parameter Sets from/to File", "group__energy__parameters__rw.html", "group__energy__parameters__rw" ],
    [ "convert_epars.h", "convert__epars_8h.html", null ],
    [ "energy_const.h", "energy__const_8h.html", null ],
    [ "params.h", "params_8h.html", null ],
    [ "read_epars.h", "read__epars_8h.html", null ],
    [ "vrna_param_s", "group__energy__parameters.html#structvrna__param__s", [
      [ "temperature", "group__energy__parameters.html#aeed2cd83713012bcb52e431041e037c8", null ],
      [ "model_details", "group__energy__parameters.html#a7b84353eb9075c595bad4ceb871bcae7", null ],
      [ "param_file", "group__energy__parameters.html#ace10aa4aacffcbf6de92349f2ee0d66a", null ]
    ] ],
    [ "vrna_exp_param_s", "group__energy__parameters.html#structvrna__exp__param__s", [
      [ "id", "group__energy__parameters.html#a378d5bcf2bae1f3ec84c912c7d3908d2", null ],
      [ "pf_scale", "group__energy__parameters.html#a53c12f0d74f94ce371e0471a8ab5a377", null ],
      [ "temperature", "group__energy__parameters.html#a674656d65ea957ddbeff8bd146b7fc16", null ],
      [ "alpha", "group__energy__parameters.html#a77145830b7bb01b36c3217b363310ef0", null ],
      [ "model_details", "group__energy__parameters.html#ac18055127bccc27c1223f1d2f3b01b53", null ],
      [ "param_file", "group__energy__parameters.html#a8e1b02a4753a9b64c3c9ae8529b9d75c", null ]
    ] ],
    [ "vrna_param_t", "group__energy__parameters.html#ga8a69ca7d787e4fd6079914f5343a1f35", null ],
    [ "vrna_exp_param_t", "group__energy__parameters.html#ga01d8b92fe734df8d79a6169482c7d8d8", null ],
    [ "paramT", "group__energy__parameters.html#ga857dde86357d306cc902f0d8b2797659", null ],
    [ "pf_paramT", "group__energy__parameters.html#ga8bffe1828e2cbec101769f5cc0b1535b", null ],
    [ "vrna_params", "group__energy__parameters.html#gad0e3e7e74bdc50d1709d40c92993185e", null ],
    [ "vrna_params_copy", "group__energy__parameters.html#ga4bffa39f26e7746148444dd8a8426eca", null ],
    [ "vrna_exp_params", "group__energy__parameters.html#gab1f3016f96aa96bff020cdd904605afa", null ],
    [ "vrna_exp_params_comparative", "group__energy__parameters.html#gaf78c09e685e6eef4100b1a41d4042550", null ],
    [ "vrna_exp_params_copy", "group__energy__parameters.html#ga70bc46be7cfa5434a71efe241c4f0609", null ],
    [ "vrna_params_subst", "group__energy__parameters.html#ga5d1909208f7ea3baa98b75afaa1f62ca", null ],
    [ "vrna_exp_params_subst", "group__energy__parameters.html#ga8e7ac4fab3b0cc03afbc134eaafb3525", null ],
    [ "vrna_exp_params_rescale", "group__energy__parameters.html#gad607bc3a5b5da16400e2ca4ea5560233", null ],
    [ "vrna_params_reset", "group__energy__parameters.html#gac40dc82e48a72a97cfc58b9da08a7792", null ],
    [ "vrna_exp_params_reset", "group__energy__parameters.html#gaa5409218068be84d7b50c78fbdaa85a9", null ],
    [ "get_scaled_pf_parameters", "group__energy__parameters.html#gabf3b9271c41dd3fac02d56e0b02b3344", null ],
    [ "get_boltzmann_factors", "group__energy__parameters.html#gaef2b931c7e9d4ffb0a5c33df50ec2068", null ],
    [ "get_boltzmann_factor_copy", "group__energy__parameters.html#ga665a446ba8ff211e551297a8fa36ec27", null ],
    [ "get_scaled_alipf_parameters", "group__energy__parameters.html#ga0ccf4e1be085a573533fd6b9da2d8cf9", null ],
    [ "get_boltzmann_factors_ali", "group__energy__parameters.html#ga2aa1d87c97f35d2e4121634a17556829", null ],
    [ "scale_parameters", "group__energy__parameters.html#ga541f2cf7436e9bc939b0a49b24baf987", null ],
    [ "get_scaled_parameters", "group__energy__parameters.html#ga7fa6a000d7c16feab939f2c4ee626197", null ]
];

==> ViennaRNA-2.4.14.tar.gz: ViennaRNA-2.4.14/doc/html/group__energy__parameters.js <==
var group__energy__parameters =
[
    [ "Reading/Writing Energy Parameter Sets from/to File", "group__energy__parameters__rw.html", "group__energy__parameters__rw" ],
    [ "basic.h", "params_2basic_8h.html", null ],
    [ "constants.h", "constants_8h.html", null ],
    [ "convert.h", "convert_8h.html", null ],
    [ "io.h", "io_8h.html", null ],
    [ "vrna_param_s", "group__energy__parameters.html#structvrna__param__s", [
      [ "temperature", "group__energy__parameters.html#aeed2cd83713012bcb52e431041e037c8", null ],
      [ "model_details", "group__energy__parameters.html#a7b84353eb9075c595bad4ceb871bcae7", null ],
      [ "param_file", "group__energy__parameters.html#ace10aa4aacffcbf6de92349f2ee0d66a", null ]
    ] ],
    [ "vrna_exp_param_s", "group__energy__parameters.html#structvrna__exp__param__s", [
      [ "id", "group__energy__parameters.html#a378d5bcf2bae1f3ec84c912c7d3908d2", null ],
      [ "pf_scale", "group__energy__parameters.html#a53c12f0d74f94ce371e0471a8ab5a377", null ],
      [ "temperature", "group__energy__parameters.html#a674656d65ea957ddbeff8bd146b7fc16", null ],
      [ "alpha", "group__energy__parameters.html#a77145830b7bb01b36c3217b363310ef0", null ],
      [ "model_details", "group__energy__parameters.html#ac18055127bccc27c1223f1d2f3b01b53", null ],
      [ "param_file", "group__energy__parameters.html#a8e1b02a4753a9b64c3c9ae8529b9d75c", null ]
    ] ],
    [ "vrna_param_t", "group__energy__parameters.html#ga8a69ca7d787e4fd6079914f5343a1f35", null ],
    [ "vrna_exp_param_t", "group__energy__parameters.html#ga01d8b92fe734df8d79a6169482c7d8d8", null ],
    [ "paramT", "group__energy__parameters.html#ga857dde86357d306cc902f0d8b2797659", null ],
    [ "pf_paramT", "group__energy__parameters.html#ga8bffe1828e2cbec101769f5cc0b1535b", null ],
    [ "vrna_params", "group__energy__parameters.html#gad0e3e7e74bdc50d1709d40c92993185e", null ],
    [ "vrna_params_copy", "group__energy__parameters.html#ga4bffa39f26e7746148444dd8a8426eca", null ],
    [ "vrna_exp_params", "group__energy__parameters.html#gab1f3016f96aa96bff020cdd904605afa", null ],
    [ "vrna_exp_params_comparative", "group__energy__parameters.html#gaf78c09e685e6eef4100b1a41d4042550", null ],
    [ "vrna_exp_params_copy", "group__energy__parameters.html#ga70bc46be7cfa5434a71efe241c4f0609", null ],
    [ "vrna_params_subst", "group__energy__parameters.html#ga5d1909208f7ea3baa98b75afaa1f62ca", null ],
    [ "vrna_exp_params_subst", "group__energy__parameters.html#ga8e7ac4fab3b0cc03afbc134eaafb3525", null ],
    [ "vrna_exp_params_rescale", "group__energy__parameters.html#gad607bc3a5b5da16400e2ca4ea5560233", null ],
    [ "vrna_params_reset", "group__energy__parameters.html#gac40dc82e48a72a97cfc58b9da08a7792", null ],
    [ "vrna_exp_params_reset", "group__energy__parameters.html#gaa5409218068be84d7b50c78fbdaa85a9", null ],
    [ "get_scaled_pf_parameters", "group__energy__parameters.html#gabf3b9271c41dd3fac02d56e0b02b3344", null ],
    [ "get_boltzmann_factors", "group__energy__parameters.html#gaef2b931c7e9d4ffb0a5c33df50ec2068", null ],
    [ "get_boltzmann_factor_copy", "group__energy__parameters.html#ga665a446ba8ff211e551297a8fa36ec27", null ],
    [ "get_scaled_alipf_parameters", "group__energy__parameters.html#ga0ccf4e1be085a573533fd6b9da2d8cf9", null ],
    [ "get_boltzmann_factors_ali", "group__energy__parameters.html#ga2aa1d87c97f35d2e4121634a17556829", null ],
    [ "scale_parameters", "group__energy__parameters.html#ga541f2cf7436e9bc939b0a49b24baf987", null ],
    [ "get_scaled_parameters", "group__energy__parameters.html#ga7fa6a000d7c16feab939f2c4ee626197", null ]
];
